module Colors
  module ColormapRegistry
    register_listed_colormap("rocket")
    register_listed_colormap("mako")
    register_listed_colormap("icefire")
    register_listed_colormap("vlag")
    register_listed_colormap("flare")
    register_listed_colormap("crest")
  end
end
